@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLURLLOGIN_H
-#define SQUID_ACLURLLOGIN_H
+#ifndef SQUID_SRC_ACL_URLLOGIN_H
+#define SQUID_SRC_ACL_URLLOGIN_H
 
 #include "acl/Acl.h"
 #include "acl/Data.h"
@@ -17,9 +17,9 @@ class ACLUrlLoginStrategy : public ACLStrategy<char const *>
 {
 
 public:
-    virtual int match (ACLData<char const *> * &, ACLFilledChecklist *);
-    virtual bool requiresRequest() const {return true;}
+    int match (ACLData<char const *> * &, ACLFilledChecklist *) override;
+    bool requiresRequest() const override {return true;}
 };
 
-#endif /* SQUID_ACLURLLOGIN_H */
+#endif /* SQUID_SRC_ACL_URLLOGIN_H */
 
