@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ANYP_PROTOCOLVERSION_H
-#define SQUID_ANYP_PROTOCOLVERSION_H
+#ifndef SQUID_SRC_ANYP_PROTOCOLVERSION_H
+#define SQUID_SRC_ANYP_PROTOCOLVERSION_H
 
 #include "anyp/ProtocolType.h"
 
@@ -40,6 +40,9 @@ public:
     unsigned int major;    ///< major version number
     unsigned int minor;    ///< minor version number
 
+    /// whether the version is "known" (e.g., has been parsed or explicitly set)
+    explicit operator bool() const { return protocol != PROTO_NONE; }
+
     bool operator==(const ProtocolVersion& that) const {
         if (this->protocol != that.protocol)
             return false;
@@ -89,12 +92,12 @@ public:
 };
 
 inline std::ostream &
-operator << (std::ostream &os, const AnyP::ProtocolVersion &v)
+operator << (std::ostream &os, const ProtocolVersion &v)
 {
     return (os << AnyP::ProtocolType_str[v.protocol] << '/' << v.major << '.' << v.minor);
 }
 
 } // namespace AnyP
 
-#endif /* SQUID_ANYP_PROTOCOLVERSION_H */
+#endif /* SQUID_SRC_ANYP_PROTOCOLVERSION_H */
 
