@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2016 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_AUTH_BASIC_USERREQUEST_H
-#define _SQUID_SRC_AUTH_BASIC_USERREQUEST_H
+#ifndef SQUID_SRC_AUTH_BASIC_USERREQUEST_H
+#define SQUID_SRC_AUTH_BASIC_USERREQUEST_H
 
 #if HAVE_AUTH_MODULE_BASIC
 
@@ -30,13 +30,13 @@ class UserRequest : public Auth::UserRequest
 
 public:
     UserRequest() {}
-    virtual ~UserRequest() { assert(LockCount()==0); }
+    ~UserRequest() override { assert(LockCount()==0); }
 
-    virtual int authenticated() const;
-    virtual void authenticate(HttpRequest * request, ConnStateData *conn, Http::HdrType type);
-    virtual Auth::Direction module_direction();
-    virtual void startHelperLookup(HttpRequest * request, AccessLogEntry::Pointer &al, AUTHCB *, void *);
-    virtual const char *credentialsStr();
+    int authenticated() const override;
+    void authenticate(HttpRequest * request, ConnStateData *conn, Http::HdrType type) override;
+    Auth::Direction module_direction() override;
+    void startHelperLookup(HttpRequest * request, AccessLogEntry::Pointer &al, AUTHCB *, void *) override;
+    const char *credentialsStr() override;
 
 private:
     static HLPCB HandleReply;
@@ -46,5 +46,5 @@ private:
 } // namespace Auth
 
 #endif /* HAVE_AUTH_MODULE_BASIC */
-#endif /* _SQUID_SRC_AUTH_BASIC_USERREQUEST_H */
+#endif /* SQUID_SRC_AUTH_BASIC_USERREQUEST_H */
 
