@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2020 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_FDE_H
-#define SQUID_FDE_H
+#ifndef SQUID_SRC_FDE_H
+#define SQUID_SRC_FDE_H
 
 #include "base/CodeContext.h" /* XXX: Remove by de-inlining ctor and clear() */
 #include "base/forward.h"
@@ -52,6 +52,13 @@ class fde
 {
 
 public:
+
+    // TODO: Merge with comm_init() to reduce initialization order dependencies.
+    /// Configures fd_table (a.k.a. fde::Table).
+    /// Call once, after learning the number of supported descriptors (i.e.
+    /// setMaxFD()) and before dereferencing fd_table (e.g., before Comm I/O).
+    static void Init();
+
     fde() {
         *ipaddr = 0;
         *desc = 0;
@@ -195,5 +202,5 @@ FD_WRITE_METHOD(int fd, const char *buf, int len)
     return fd_table[fd].write(fd, buf, len);
 }
 
-#endif /* SQUID_FDE_H */
+#endif /* SQUID_SRC_FDE_H */
 
