@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2020 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -11,6 +11,7 @@
 #include "squid.h"
 #include "AccessLogEntry.h"
 #include "base/TextException.h"
+#include "CacheManager.h"
 #include "comm.h"
 #include "comm/Connection.h"
 #include "comm/Write.h"
@@ -25,7 +26,7 @@
 #include "mgr/IntParam.h"
 #include "mgr/Request.h"
 #include "mgr/Response.h"
-#include "SquidTime.h"
+
 #include <memory>
 #include <algorithm>
 
@@ -39,7 +40,7 @@ Mgr::Inquirer::Inquirer(Action::Pointer anAction,
     conn = aCause.conn;
     Ipc::ImportFdIntoComm(conn, SOCK_STREAM, IPPROTO_TCP, Ipc::fdnHttpSocket);
 
-    debugs(16, 5, HERE << conn << " action: " << aggrAction);
+    debugs(16, 5, conn << " action: " << aggrAction);
 
     closer = asyncCall(16, 5, "Mgr::Inquirer::noteCommClosed",
                        CommCbMemFunT<Inquirer, CommCloseCbParams>(this, &Inquirer::noteCommClosed));
@@ -59,31 +60,36 @@ Mgr::Inquirer::cleanup()
 void
 Mgr::Inquirer::removeCloseHandler()
 {
-    if (closer != NULL) {
+    if (closer != nullptr) {
         comm_remove_close_handler(conn->fd, closer);
-        closer = NULL;
+        closer = nullptr;
     }
 }
 
 void
 Mgr::Inquirer::start()
 {
-    debugs(16, 5, HERE);
+    debugs(16, 5, MYNAME);
     Ipc::Inquirer::start();
     Must(Comm::IsConnOpen(conn));
-    Must(aggrAction != NULL);
+    Must(aggrAction != nullptr);
+
+    const auto &origin = aggrAction->command().params.httpOrigin;
+    const auto originOrNil = origin.size() ? origin.termedBuf() : nullptr;
 
     std::unique_ptr<MemBuf> replyBuf;
     if (strands.empty()) {
         const char *url = aggrAction->command().params.httpUri.termedBuf();
-        const MasterXaction::Pointer mx = new MasterXaction(XactionInitiator::initIpc);
+        const auto mx = MasterXaction::MakePortless<XactionInitiator::initIpc>();
         auto *req = HttpRequest::FromUrlXXX(url, mx);
         ErrorState err(ERR_INVALID_URL, Http::scNotFound, req, nullptr);
         std::unique_ptr<HttpReply> reply(err.BuildHttpReply());
+        CacheManager::PutCommonResponseHeaders(*reply, originOrNil);
         replyBuf.reset(reply->pack());
     } else {
         std::unique_ptr<HttpReply> reply(new HttpReply);
-        reply->setHeaders(Http::scOkay, NULL, "text/plain", -1, squid_curtime, squid_curtime);
+        reply->setHeaders(Http::scOkay, nullptr, "text/plain", -1, squid_curtime, squid_curtime);
+        CacheManager::PutCommonResponseHeaders(*reply, originOrNil);
         reply->header.putStr(Http::HdrType::CONNECTION, "close"); // until we chunk response
         replyBuf.reset(reply->pack());
     }
@@ -96,8 +102,8 @@ Mgr::Inquirer::start()
 void
 Mgr::Inquirer::noteWroteHeader(const CommIoCbParams& params)
 {
-    debugs(16, 5, HERE);
-    writer = NULL;
+    debugs(16, 5, MYNAME);
+    writer = nullptr;
     Must(params.flag == Comm::OK);
     Must(params.conn.getRaw() == conn.getRaw());
     Must(params.size != 0);
@@ -107,11 +113,14 @@ Mgr::Inquirer::noteWroteHeader(const CommIoCbParams& params)
 
 /// called when the HTTP client or some external force closed our socket
 void
-Mgr::Inquirer::noteCommClosed(const CommCloseCbParams& params)
+Mgr::Inquirer::noteCommClosed(const CommCloseCbParams &)
 {
-    debugs(16, 5, HERE);
-    Must(!Comm::IsConnOpen(conn) && params.conn.getRaw() == conn.getRaw());
-    conn = NULL;
+    debugs(16, 5, MYNAME);
+    closer = nullptr;
+    if (conn) {
+        conn->noteClosure();
+        conn = nullptr;
+    }
     mustStop("commClosed");
 }
 
@@ -130,7 +139,7 @@ Mgr::Inquirer::sendResponse()
     if (!strands.empty() && aggrAction->aggregatable()) {
         removeCloseHandler();
         AsyncJob::Start(new ActionWriter(aggrAction, conn));
-        conn = NULL; // should not close because we passed it to ActionWriter
+        conn = nullptr; // should not close because we passed it to ActionWriter
     }
 }
 
@@ -148,10 +157,10 @@ Mgr::Inquirer::applyQueryParams(const Ipc::StrandCoords& aStrands, const QueryPa
     QueryParam::Pointer processesParam = aParams.get("processes");
     QueryParam::Pointer workersParam = aParams.get("workers");
 
-    if (processesParam == NULL || workersParam == NULL) {
-        if (processesParam != NULL) {
+    if (processesParam == nullptr || workersParam == nullptr) {
+        if (processesParam != nullptr) {
             IntParam* param = dynamic_cast<IntParam*>(processesParam.getRaw());
-            if (param != NULL && param->type == QueryParam::ptInt) {
+            if (param != nullptr && param->type == QueryParam::ptInt) {
                 const std::vector<int>& processes = param->value();
                 for (Ipc::StrandCoords::const_iterator iter = aStrands.begin();
                         iter != aStrands.end(); ++iter) {
@@ -159,9 +168,9 @@ Mgr::Inquirer::applyQueryParams(const Ipc::StrandCoords& aStrands, const QueryPa
                         sc.push_back(*iter);
                 }
             }
-        } else if (workersParam != NULL) {
+        } else if (workersParam != nullptr) {
             IntParam* param = dynamic_cast<IntParam*>(workersParam.getRaw());
-            if (param != NULL && param->type == QueryParam::ptInt) {
+            if (param != nullptr && param->type == QueryParam::ptInt) {
                 const std::vector<int>& workers = param->value();
                 for (int i = 0; i < (int)aStrands.size(); ++i) {
                     if (std::find(workers.begin(), workers.end(), i + 1) != workers.end())
@@ -173,9 +182,9 @@ Mgr::Inquirer::applyQueryParams(const Ipc::StrandCoords& aStrands, const QueryPa
         }
     }
 
-    debugs(16, 4, HERE << "strands kid IDs = ");
+    debugs(16, 4, "strands kid IDs = ");
     for (Ipc::StrandCoords::const_iterator iter = sc.begin(); iter != sc.end(); ++iter) {
-        debugs(16, 4, HERE << iter->kidId);
+        debugs(16, 4, iter->kidId);
     }
 
     return sc;
