@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2020 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -7,6 +7,7 @@
  */
 
 #include "squid.h"
+#include "base/Raw.h"
 #include "ErrorDetail.h"
 #include "ErrorDetailManager.h"
 #include "errorpage.h"
@@ -36,7 +37,7 @@ public:
 
 private:
     ErrorDetailsList::Pointer  theDetails;
-    virtual bool parse() override;
+    bool parse() override;
 };
 }// namespace Ssl
 
@@ -63,7 +64,7 @@ Ssl::ErrorDetailsList::getErrorDescr(Security::ErrorCode value)
         return it->second.descr.termedBuf();
     }
 
-    return NULL;
+    return nullptr;
 }
 
 const char *
@@ -74,10 +75,10 @@ Ssl::ErrorDetailsList::getErrorDetail(Security::ErrorCode value)
         return it->second.detail.termedBuf();
     }
 
-    return NULL;
+    return nullptr;
 }
 
-Ssl::ErrorDetailsManager *Ssl::ErrorDetailsManager::TheDetailsManager = NULL;
+Ssl::ErrorDetailsManager *Ssl::ErrorDetailsManager::TheDetailsManager = nullptr;
 
 Ssl::ErrorDetailsManager &Ssl::ErrorDetailsManager::GetInstance()
 {
@@ -91,7 +92,7 @@ Ssl::ErrorDetailsManager &Ssl::ErrorDetailsManager::GetInstance()
 void Ssl::ErrorDetailsManager::Shutdown()
 {
     delete TheDetailsManager;
-    TheDetailsManager = NULL;
+    TheDetailsManager = nullptr;
 }
 
 Ssl::ErrorDetailsManager::ErrorDetailsManager()
@@ -106,11 +107,11 @@ Ssl::ErrorDetailsList::Pointer Ssl::ErrorDetailsManager::getCachedDetails(const
     Cache::iterator it;
     it = cache.find(lang);
     if (it != cache.end()) {
-        debugs(83, 8, HERE << "Found template details in cache for language: " << lang);
+        debugs(83, 8, "Found template details in cache for language: " << lang);
         return it->second;
     }
 
-    return NULL;
+    return nullptr;
 }
 
 void Ssl::ErrorDetailsManager::cacheDetails(ErrorDetailsList::Pointer &errorDetails)
@@ -126,8 +127,8 @@ Ssl::ErrorDetailsManager::getErrorDetail(Security::ErrorCode value, const HttpRe
 {
 #if USE_ERR_LOCALES
     String hdr;
-    if (request != NULL && request->header.getList(Http::HdrType::ACCEPT_LANGUAGE, &hdr)) {
-        ErrorDetailsList::Pointer errDetails = NULL;
+    if (request != nullptr && request->header.getList(Http::HdrType::ACCEPT_LANGUAGE, &hdr)) {
+        ErrorDetailsList::Pointer errDetails = nullptr;
         //Try to retrieve from cache
         size_t pos = 0;
         char lang[256];
@@ -136,26 +137,28 @@ Ssl::ErrorDetailsManager::getErrorDetail(Security::ErrorCode value, const HttpRe
         errDetails = getCachedDetails(lang); // search in cache
 
         if (!errDetails) { // Else try to load from disk
-            debugs(83, 8, HERE << "Creating new ErrDetailList to read from disk");
+            debugs(83, 8, "Creating new ErrDetailList to read from disk");
             errDetails = new ErrorDetailsList();
             ErrorDetailFile detailTmpl(errDetails);
             if (detailTmpl.loadFor(request.getRaw())) {
                 if (detailTmpl.language()) {
-                    debugs(83, 8, HERE << "Found details on disk for language " << detailTmpl.language());
+                    debugs(83, 8, "Found details on disk for language " << detailTmpl.language());
                     errDetails->errLanguage = detailTmpl.language();
                     cacheDetails(errDetails);
                 }
             }
         }
 
-        if (errDetails != NULL && errDetails->getRecord(value, entry))
+        if (errDetails != nullptr && errDetails->getRecord(value, entry))
             return true;
     }
+#else
+    (void)request;
 #endif
 
     // else try the default
     if (theDefaultErrorDetails->getRecord(value, entry)) {
-        debugs(83, 8, HERE << "Found default details record for error: " << GetErrorName(value));
+        debugs(83, 8, "Found default details record for error: " << GetErrorName(value));
         return true;
     }
 
@@ -198,11 +201,11 @@ Ssl::ErrorDetailFile::parse()
         auto *s = buf.c_str();
         const auto e = s + size;
 
-        //ignore spaces, new lines and comment lines (starting with #) at the beggining
+        //ignore spaces, new lines and comment lines (starting with #) at the beginning
         for (; (*s == '\n' || *s == ' '  || *s == '\t' || *s == '#')  && s < e; ++s) {
             if (*s == '#')
                 while (s<e &&  *s != '\n')
-                    ++s; // skip untill the end of line
+                    ++s; // skip until the end of line
         }
 
         if ( s != e) {
@@ -210,15 +213,13 @@ Ssl::ErrorDetailFile::parse()
             Http::ContentLengthInterpreter interpreter;
             // no applyStatusCodeRules() -- error templates lack HTTP status code
             if (!parser.parse(s, e - s, interpreter)) {
-                debugs(83, DBG_IMPORTANT, HERE <<
-                       "WARNING! parse error on:" << s);
+                debugs(83, DBG_IMPORTANT, "WARNING: parse error on:" << s);
                 return false;
             }
 
             const String errorName = parser.getByName("name");
             if (!errorName.size()) {
-                debugs(83, DBG_IMPORTANT, HERE <<
-                       "WARNING! invalid or no error detail name on:" << s);
+                debugs(83, DBG_IMPORTANT, "WARNING: invalid or no error detail name on:" << s);
                 return false;
             }
 
@@ -226,8 +227,7 @@ Ssl::ErrorDetailFile::parse()
             if (ssl_error != SSL_ERROR_NONE) {
 
                 if (theDetails->getErrorDetail(ssl_error)) {
-                    debugs(83, DBG_IMPORTANT, HERE <<
-                           "WARNING! duplicate entry: " << errorName);
+                    debugs(83, DBG_IMPORTANT, "WARNING: duplicate entry: " << errorName);
                     return false;
                 }
 
@@ -241,14 +241,12 @@ Ssl::ErrorDetailFile::parse()
                 // TODO: Validate "descr" and "detail" field values.
 
                 if (!detailsParseOk || !descrParseOk) {
-                    debugs(83, DBG_IMPORTANT, HERE <<
-                           "WARNING! missing important field for detail error: " <<  errorName);
+                    debugs(83, DBG_IMPORTANT, "WARNING: missing important field for detail error: " <<  errorName);
                     return false;
                 }
 
             } else if (!Ssl::ErrorIsOptional(errorName.termedBuf())) {
-                debugs(83, DBG_IMPORTANT, HERE <<
-                       "WARNING! invalid error detail name: " << errorName);
+                debugs(83, DBG_IMPORTANT, "WARNING: invalid error detail name: " << errorName);
                 return false;
             }
 
